Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(246)

Unified Diff: chrome/browser/chromeos/login/screens/update_view.h

Issue 2684473002: Revert of Fold UpdateModel into UpdateScreen. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/screens/update_view.h
diff --git a/chrome/browser/chromeos/login/screens/update_view.h b/chrome/browser/chromeos/login/screens/update_view.h
index 17de164fb55b1f9daecf323a44cfbe325afabe0b..58c33916c8a723f114899788cfc54b85eef20e7b 100644
--- a/chrome/browser/chromeos/login/screens/update_view.h
+++ b/chrome/browser/chromeos/login/screens/update_view.h
@@ -9,7 +9,7 @@
namespace chromeos {
-class UpdateScreen;
+class UpdateModel;
// Interface for dependency injection between NetworkScreen and its actual
// representation. Owned by UpdateScreen.
@@ -23,10 +23,10 @@
// Hides the contents of the screen.
virtual void Hide() = 0;
- // Binds |screen| to the view.
- virtual void Bind(UpdateScreen* screen) = 0;
+ // Binds |model| to the view.
+ virtual void Bind(UpdateModel& model) = 0;
- // Unbinds the screen from the view.
+ // Unbinds model from the view.
virtual void Unbind() = 0;
};
« no previous file with comments | « chrome/browser/chromeos/login/screens/update_screen.cc ('k') | chrome/browser/ui/webui/chromeos/login/update_screen_handler.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698